from typing import Dict, List, Optional, Union

class PyKakasiException(Exception): ...
class UnknownCharacterException(PyKakasiException): ...
class UnsupportedRomanRulesException(PyKakasiException): ...
class UnknownOptionsException(PyKakasiException): ...
class InvalidModeValueException(PyKakasiException): ...
class InvalidFlagValueException(PyKakasiException): ...

class kakasi:
    def __init__(self) -> None: ...
    def convert(self, text: str) -> List[Dict[str, str]]: ...
    def setMode(self, fr: str, to: Optional[Union[bool, str]]) -> None: ...
    def getConverter(self): ...
    def do(self, text: str) -> str: ...

class wakati(kakasi):
    def __init__(self) -> None: ...
    def getConverter(self): ...
    def setMode(self, fr: str, to: Optional[Union[bool, str]]) -> None: ...
    def do(self, text: str) -> str: ...

# Names in __all__ with no definition:
#   exceptions



from typing import Any, Tuple

from .properties import Configurations as Configurations
from .scripts import H2 as H2

class J2:
    convert: Any = ...
    def __init__(self, mode: str = ..., method: str = ...) -> None: ...
    def isRegion(self, c: str) -> Any: ...
    def isCletter(self, literal: str, c: str) -> bool: ...
    def convert_h(self, itext: Any) -> Tuple[str, int]: ...
    def convert_nonh(self, text: Any): ...
    def convert_noop(self, text: Any): ...

class Itaiji:
    __dict__: Any = ...
    def __new__(cls, *p: Any, **k: Any): ...
    def __init__(self) -> None: ...
    def haskey(self, c: Any): ...
    def convert(self, text: str) -> str: ...

class Kanwa:
    __dict__: Any = ...
    def __new__(cls, *p: Any, **k: Any): ...
    def __init__(self) -> None: ...
    def load(self, char: str) -> Any: ...
